@@ -64,7 +64,7 @@ extern "C"
                   double& TOL,
                   F77_INT* IWORK,
                   double* DWORK, F77_INT& LDWORK,
-                  bool* BWORK,
+                  F77_LOGICAL* BWORK,
                   F77_INT& IWARN, F77_INT& INFO);
 
     int F77_FUNC (ib01cd, IB01CD)
@@ -516,7 +516,7 @@ For internal use only.")
 
         OCTAVE_LOCAL_BUFFER (F77_INT, iwork_b, liwork_b);
         OCTAVE_LOCAL_BUFFER (double, dwork_b, ldwork_b);
-        OCTAVE_LOCAL_BUFFER (bool, bwork, 2*n);
+        OCTAVE_LOCAL_BUFFER (F77_LOGICAL, bwork, 2*n);
 
 
         // error indicators
